<!-- markdownlint-disable MD041 -->
```{toctree}
:hidden:

Installing <https://torii.shmdn.link/latest/install.html#installing-board-definitions>

gowin/index
altera/index
lattice/index
quicklogic/index
xilinx/index

Torii HDL <https://shrine-maiden-heavy-industries.github.io/torii-hdl/>
```

```{toctree}
:caption: Development
:hidden:

Source Code <https://github.com/shrine-maiden-heavy-industries/torii-boards/>
Contributing <https://github.com/shrine-maiden-heavy-industries/torii-boards/blob/main/CONTRIBUTING.md>

changelog
license
```

# Torii-HDL Board Definitions

This package contains a collection of board definitions for [Torii], primarily FPGA evaluation boards, but other board files are also planned and welcome to help expand the ecosystem.

## Community

The two primary community spots for Torii and by extension Torii Boards are the `#torii` IRC channel on [libera.chat] (`irc.libera.chat:6697`) which you can join via your favorite IRC client or the [web chat], and the [discussion forum] on GitHub.

Please do join and share your projects using Torii, ask questions, get help with problems, or discuss development.

[Torii]: https://github.com/shrine-maiden-heavy-industries/torii-hdl
[libera.chat]: https://libera.chat/
[web chat]: https://web.libera.chat/#torii
[discussion forum]: https://github.com/shrine-maiden-heavy-industries/torii-boards/discussions
